@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006, 2007 Øyvind Kolås <pippin@gimp.org>
  */
@@ -26,6 +26,7 @@
 #include "gegl-tile-handler-empty.h"
 #include "gegl-tile-handler-zoom.h"
 #include "gegl-tile-handler-private.h"
+#include "gegl-config.h"
 
 
 G_DEFINE_TYPE (GeglTileStorage, gegl_tile_storage, GEGL_TYPE_TILE_HANDLER_CHAIN)
@@ -119,6 +120,90 @@ gegl_tile_storage_remove_handler (GeglTileStorage *tile_storage,
   gegl_tile_handler_chain_bind (chain);
 }
 
+GeglTile *
+gegl_tile_storage_steal_hot_tile (GeglTileStorage *tile_storage)
+{
+  GeglTile *tile;
+
+  if (gegl_config_threads()>1)
+    {
+      tile = g_atomic_pointer_get (&tile_storage->hot_tile);
+
+      if (tile &&
+          ! g_atomic_pointer_compare_and_exchange (&tile_storage->hot_tile,
+                                                   tile, NULL))
+        {
+          tile = NULL;
+        }
+    }
+  else
+    {
+      tile                   = tile_storage->hot_tile;
+      tile_storage->hot_tile = NULL;
+    }
+
+  return tile;
+}
+
+GeglTile *
+gegl_tile_storage_try_steal_hot_tile (GeglTileStorage *tile_storage,
+                                      GeglTile        *tile)
+{
+  if (gegl_config_threads()>1)
+    {
+      if (tile &&
+          ! g_atomic_pointer_compare_and_exchange (&tile_storage->hot_tile,
+                                                   tile, NULL))
+        {
+          tile = NULL;
+        }
+    }
+  else
+    {
+      if (tile_storage->hot_tile == tile)
+        tile_storage->hot_tile = NULL;
+      else
+        tile                   = NULL;
+    }
+
+  return tile;
+}
+
+void
+gegl_tile_storage_take_hot_tile (GeglTileStorage *tile_storage,
+                                 GeglTile        *tile)
+{
+  if (gegl_config_threads()>1)
+    {
+      if (! g_atomic_pointer_compare_and_exchange (&tile_storage->hot_tile,
+                                                   NULL, tile))
+        {
+          gegl_tile_unref (tile);
+        }
+    }
+  else
+    {
+      if (! tile_storage->hot_tile)
+        tile_storage->hot_tile = tile;
+      else
+        gegl_tile_unref (tile);
+    }
+}
+
+static void
+gegl_tile_storage_dispose (GObject *object)
+{
+  GeglTileStorage *self = GEGL_TILE_STORAGE (object);
+
+  /* disconnect the cache before destruction, to avoid a race condition with
+   * other threads trimming the global cache through an unrelated cache
+   * handler.  see bug #795597.
+   */
+  gegl_tile_handler_cache_disconnect (self->cache);
+
+  (*G_OBJECT_CLASS (parent_class)->dispose)(object);
+}
+
 static void
 gegl_tile_storage_finalize (GObject *object)
 {
@@ -135,6 +220,7 @@ gegl_tile_storage_class_init (GeglTileStorageClass *class)
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
 
   parent_class                = g_type_class_peek_parent (class);
+  gobject_class->dispose      = gegl_tile_storage_dispose;
   gobject_class->finalize     = gegl_tile_storage_finalize;
 
   gegl_tile_storage_signals[CHANGED] =
