@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this library; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006,2007,2015,2018 Øyvind Kolås <pippin@gimp.org>
  *           2013 Daniel Sabo
@@ -64,7 +64,7 @@ gegl_downscale_2x2_generic (const Babl *format,
                             guchar     *dst_data,
                             gint        dst_rowstride)
 {
-  const Babl *tmp_format = gegl_babl_rgba_linear_float ();
+  const Babl *tmp_format = babl_format_with_space ("RGBA float", format);
   const Babl *from_fish  = babl_fish (format, tmp_format);
   const Babl *to_fish    = babl_fish (tmp_format, format);
   const gint tmp_bpp     = 4 * 4;
@@ -135,11 +135,9 @@ void _gegl_init_u8_lut (void)
     lut_u8_to_u16f[i] = lut_u8_to_u16[i];
   }
 
-  /* workaround for bug, doing this conversion sample by sample */
-  for (i = 0; i < 65536/LUT_DIVISOR; i++)
-    babl_process (babl_fish (babl_format ("Y u16"), babl_format("Y' u8")),
-                  &u16_ramp[i], &lut_u16_to_u8[i],
-                  1);
+  babl_process (babl_fish (babl_format ("Y u16"), babl_format("Y' u8")),
+                &u16_ramp[0], &lut_u16_to_u8[0],
+                65536/LUT_DIVISOR);
 
   lut_inited = 1;
 }
@@ -1003,7 +1001,7 @@ gegl_resample_boxfilter_generic (guchar       *dest_buf,
                                  const Babl *format,
                                  gint d_rowstride)
 {
-  const Babl *tmp_format = gegl_babl_rgba_linear_float ();
+  const Babl *tmp_format = babl_format_with_space ("RGBA float", format);
   const Babl *from_fish  = babl_fish (format, tmp_format);
   const Babl *to_fish    = babl_fish (tmp_format, format);
 
@@ -1110,7 +1108,7 @@ gegl_resample_bilinear_generic (guchar              *dest_buf,
                                 const Babl          *format,
                                 gint                 d_rowstride)
 {
-  const Babl *tmp_format = gegl_babl_rgba_linear_float ();
+  const Babl *tmp_format = babl_format_with_space ("RGBA float", format);
   const Babl *from_fish  = babl_fish (format, tmp_format);
   const Babl *to_fish    = babl_fish (tmp_format, format);
 
