@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2003      Calvin Williamson
  * 2005-2009,2011-2014 Øyvind Kolås
@@ -181,6 +181,9 @@ gegl_operation_get_bounding_box (GeglOperation *self)
   GeglOperationClass *klass = GEGL_OPERATION_GET_CLASS (self);
   GeglRectangle       rect  = { 0, 0, 0, 0 };
 
+  g_return_val_if_fail (GEGL_IS_OPERATION (self), rect);
+  g_return_val_if_fail (GEGL_IS_NODE (self->node), rect);
+
   if (self->node->passthrough)
   {
     GeglRectangle  result = { 0, 0, 0, 0 };
@@ -854,3 +857,12 @@ void gegl_operation_progress (GeglOperation *operation,
   if (operation->node)
     gegl_node_progress (operation->node, progress, message);
 }
+
+const Babl *
+gegl_operation_get_source_space (GeglOperation *operation, const char *in_pad)
+{
+ const Babl *source_format = gegl_operation_get_source_format (operation, "input");
+  if (source_format)
+    return babl_format_get_space (source_format);
+  return NULL;
+}
