@@ -11,7 +11,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2011 Robert Sasu <sasu.robert@gmail.com>
  *
@@ -73,8 +73,9 @@ typedef struct
 static void
 prepare (GeglOperation *operation)
 {
-  GeglProperties              *o       = GEGL_PROPERTIES (operation);
+  GeglProperties          *o       = GEGL_PROPERTIES (operation);
   GeglOperationAreaFilter *op_area = GEGL_OPERATION_AREA_FILTER (operation);
+  const Babl              *space   = gegl_operation_get_source_space (operation, "input");
 
   gint tmp;
   /*
@@ -88,8 +89,8 @@ prepare (GeglOperation *operation)
 
   op_area->left = op_area->right = op_area->top = op_area->bottom = tmp;
 
-  gegl_operation_set_format (operation, "input", babl_format ("RGBA float"));
-  gegl_operation_set_format (operation, "output", babl_format ("RGBA float"));
+  gegl_operation_set_format (operation, "input", babl_format_with_space ("RGBA float", space));
+  gegl_operation_set_format (operation, "output", babl_format_with_space ("RGBA float", space));
 }
 
 static inline gdouble
@@ -447,9 +448,10 @@ process (GeglOperation       *operation,
 {
   GeglProperties          *o         = GEGL_PROPERTIES (operation);
   GeglOperationAreaFilter *op_area   = GEGL_OPERATION_AREA_FILTER (operation);
+  GeglSampler             *sampler;
   GeglRectangle            boundary  = get_effective_area (operation);
   GeglRectangle            extended;
-  const Babl              *format    = babl_format ("RGBA float");
+  const Babl              *format    = gegl_operation_get_format (operation, "output");
 
   GRand  *gr = g_rand_new_with_seed (o->seed);
   gfloat  color[4];
@@ -461,6 +463,10 @@ process (GeglOperation       *operation,
   Polygon poly;
   gint    i;
 
+  sampler = gegl_buffer_sampler_new_at_level (input,
+                                              format, GEGL_SAMPLER_NEAREST,
+                                              level);
+
   extended.x      = CLAMP (result->x - op_area->left, boundary.x, boundary.x +
                            boundary.width);
   extended.width  = CLAMP (result->width + op_area->left + op_area->right, 0,
@@ -534,14 +540,14 @@ process (GeglOperation       *operation,
       ix = CLAMP (x, boundary.x, boundary.x + boundary.width - 1);
       iy = CLAMP (y, boundary.y, boundary.y + boundary.height - 1);
 
-      gegl_buffer_sample_at_level (input, ix, iy, NULL, color, format, level,
-                          GEGL_SAMPLER_NEAREST, GEGL_ABYSS_NONE);
+      gegl_sampler_get (sampler, ix, iy, NULL, color, GEGL_ABYSS_NONE);
 
       fill_poly_color (&poly, &extended, &boundary, dst_buf, color);
     }
 
   gegl_buffer_set (output, &extended, 0, format, dst_buf, GEGL_AUTO_ROWSTRIDE);
 
+  g_object_unref (sampler);
   g_free (dst_buf);
   g_free (random_indices);
   g_free (gr);
