@@ -11,7 +11,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Hirotsuna Mizuno <s1041150@u-aizu.ac.jp>
  *
@@ -208,8 +208,9 @@ attach (GeglOperation *self)
 static void
 prepare (GeglOperation *operation)
 {
-  const Babl *inout_format = babl_format ("R'G'B'A float");
-  const Babl *aux_format   = babl_format ("Y'A float");
+  const Babl *space        = gegl_operation_get_source_space (operation, "input");
+  const Babl *inout_format = babl_format_with_space ("R'G'B'A float", space);
+  const Babl *aux_format   = babl_format_with_space ("Y'A float", space);
 
   gegl_operation_set_format (operation, "input",  inout_format);
   gegl_operation_set_format (operation, "output", inout_format);
