@@ -11,7 +11,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * Polarize plug-in --- maps a rectangle to a circle or vice-versa
  * Copyright (C) 1997 Daniel Dunbar
@@ -82,15 +82,6 @@ property_boolean (middle, _("Choose middle"), TRUE)
 #define SCALE_WIDTH     200
 #define ENTRY_WIDTH      60
 
-static void
-prepare (GeglOperation *operation)
-{
-  gegl_operation_set_format (operation, "input",
-                             babl_format ("RGBA float"));
-  gegl_operation_set_format (operation, "output",
-                             babl_format ("RGBA float"));
-}
-
 static gboolean
 calc_undistorted_coords (gdouble        wx,
                          gdouble        wy,
@@ -325,7 +316,7 @@ process (GeglOperation       *operation,
 {
   GeglProperties          *o            = GEGL_PROPERTIES (operation);
   GeglRectangle            boundary     = get_effective_area (operation);
-  const Babl              *format       = babl_format ("RGBA float");
+  const Babl              *format       = gegl_operation_get_format (operation, "output");
   GeglSampler             *sampler      = gegl_buffer_sampler_new_at_level (
                                     input, format, GEGL_SAMPLER_NOHALO,
                                     level);
@@ -411,7 +402,6 @@ gegl_op_class_init (GeglOpClass *klass)
   operation_class = GEGL_OPERATION_CLASS (klass);
   filter_class    = GEGL_OPERATION_FILTER_CLASS (klass);
 
-  operation_class->prepare                 = prepare;
   operation_class->get_required_for_output = get_required_for_output;
 
   filter_class->process                    = process;
