@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006, 2010 Øyvind Kolås <pippin@gimp.org>
  */
@@ -72,7 +72,9 @@ attach (GeglOperation *operation)
   translate = gegl_node_new_child (gegl, "operation", "gegl:translate", NULL);
   opacity   = gegl_node_new_child (gegl, "operation", "gegl:opacity", NULL);
   blur      = gegl_node_new_child (gegl, "operation", "gegl:gaussian-blur", 
-                                         "clip-extent", FALSE, NULL);
+                                         "clip-extent", FALSE, 
+                                         "abyss-policy", 0,
+                                         NULL);
   darken    = gegl_node_new_child (gegl, "operation", "gegl:src-in", NULL);
   color     = gegl_node_new_child (gegl, "operation", "gegl:color",
                                    "value", black_color,
@@ -107,7 +109,8 @@ gegl_op_class_init (GeglOpClass *klass)
 
   gegl_operation_class_set_keys (operation_class,
     "name",        "gegl:dropshadow",
-    "categories",  "effects:light",
+    "categories",  "light",
+    "title",       _("Dropshadow"),
     "description",
     _("Creates a dropshadow effect on the input buffer"),
     NULL);
