@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  *
  * Neon filter for GIMP for BIPS
@@ -95,9 +95,11 @@ static void      combine_to_gradient (gfloat           *dest,
 
 static void neon_prepare (GeglOperation *operation)
 {
-  //const Babl *src_format = gegl_operation_get_source_format (operation, "input");
-  gegl_operation_set_format (operation, "input", babl_format ("R'G'B'A float"));
-  gegl_operation_set_format (operation, "output", babl_format("R'G'B'A float"));
+  const Babl *space = gegl_operation_get_source_space (operation, "input");
+  const Babl *format = babl_format_with_space ("R'G'B'A float", space);
+
+  gegl_operation_set_format (operation, "input", format);
+  gegl_operation_set_format (operation, "output", format);
 }
 
 
@@ -122,7 +124,7 @@ neon_process (GeglOperation     *op,
     gdouble       vanish_pt;
 
     /* Retrieve a pointer to GeglProperties via Chant */
-    const Babl *rgba32 = babl_format("R'G'B'A float");
+    const Babl *rgba32 = gegl_operation_get_format (op, "output");
     GeglProperties *o = GEGL_PROPERTIES (op);
     gdouble      radius, amount;
     gdouble      std_dev;
@@ -550,7 +552,7 @@ gegl_op_class_init (GeglOpClass *klass)
     "name",       "gegl:edge-neon",
     "title",      _("Neon Edge Detection"),
     "categories", "edge-detect",
-    "reference-hash", "30ccc2c2c75a2c19e07e3c63f150a492",
+    "reference-hash", "fbed8a5280621f743e765958dd3879a8",
     "description",
         _("Performs edge detection using a Gaussian derivative method"),
         NULL);
