@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006 Dominik Ernst <dernst@gmx.de>
  * Copyright 2013 Massimo Valentini <mvalentini@src.gnome.org>
@@ -933,6 +933,7 @@ filter_disambiguation (GeglGblur1dFilter filter,
 static void
 gegl_gblur_1d_prepare (GeglOperation *operation)
 {
+  const Babl *space = gegl_operation_get_source_space (operation, "input");
   GeglProperties *o = GEGL_PROPERTIES (operation);
   const Babl *src_format = gegl_operation_get_source_format (operation, "input");
   const char *format     = "RaGaBaA float";
@@ -947,26 +948,27 @@ gegl_gblur_1d_prepare (GeglOperation *operation)
     {
       const Babl *model = babl_format_get_model (src_format);
 
-      if (model == babl_model ("RGB") || model == babl_model ("R'G'B'"))
+      if (babl_model_is (model, "RGB") ||
+          babl_model_is (model, "R'G'B'"))
         {
           format = "RGB float";
           o->user_data = iir_young_blur_1D_rgb;
         }
-      else if (model == babl_model ("Y") || model == babl_model ("Y'"))
+      else if (babl_model_is (model, "Y") || babl_model_is (model, "Y'"))
         {
           format = "Y float";
           o->user_data = iir_young_blur_1D_y;
         }
-      else if (model == babl_model ("YA") || model == babl_model ("Y'A") ||
-               model == babl_model ("YaA") || model == babl_model ("Y'aA"))
+      else if (babl_model_is (model, "YA") || babl_model_is (model, "Y'A") ||
+               babl_model_is (model, "YaA") || babl_model_is (model, "Y'aA"))
         {
           format = "YaA float";
           o->user_data = iir_young_blur_1D_yA;
         }
     }
 
-  gegl_operation_set_format (operation, "input", babl_format (format));
-  gegl_operation_set_format (operation, "output", babl_format (format));
+  gegl_operation_set_format (operation, "input", babl_format_with_space (format, space));
+  gegl_operation_set_format (operation, "output", babl_format_with_space (format, space));
 }
 
 static GeglRectangle
