@@ -38,6 +38,7 @@ void gegl_op_grey_register_type(GTypeModule *module);
 void gegl_op_grid_register_type(GTypeModule *module);
 void gegl_op_high_pass_register_type(GTypeModule *module);
 void gegl_op_hue_chroma_register_type(GTypeModule *module);
+void gegl_op_icc_save_register_type(GTypeModule *module);
 void gegl_op_image_compare_register_type(GTypeModule *module);
 void gegl_op_image_gradient_register_type(GTypeModule *module);
 void gegl_op_introspect_register_type(GTypeModule *module);
@@ -46,6 +47,7 @@ void gegl_op_invert_linear_register_type(GTypeModule *module);
 void gegl_op_layer_register_type(GTypeModule *module);
 void gegl_op_levels_register_type(GTypeModule *module);
 void gegl_op_linear_gradient_register_type(GTypeModule *module);
+void gegl_op_little_planet_register_type(GTypeModule *module);
 void gegl_op_magick_load_register_type(GTypeModule *module);
 void gegl_op_mantiuk06_register_type(GTypeModule *module);
 void gegl_op_map_absolute_register_type(GTypeModule *module);
@@ -162,6 +164,7 @@ gegl_module_register (GTypeModule *module)
   gegl_op_grid_register_type(module);
   gegl_op_high_pass_register_type(module);
   gegl_op_hue_chroma_register_type(module);
+  gegl_op_icc_save_register_type(module);
   gegl_op_image_compare_register_type(module);
   gegl_op_image_gradient_register_type(module);
   gegl_op_introspect_register_type(module);
@@ -170,6 +173,7 @@ gegl_module_register (GTypeModule *module)
   gegl_op_layer_register_type(module);
   gegl_op_levels_register_type(module);
   gegl_op_linear_gradient_register_type(module);
+  gegl_op_little_planet_register_type(module);
   gegl_op_magick_load_register_type(module);
   gegl_op_mantiuk06_register_type(module);
   gegl_op_map_absolute_register_type(module);
