@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2011 Øyvind Kolås <pippin@gimp.org>
  */
@@ -45,7 +45,7 @@ property_double (softness, _("Softness"), 0.8)
 
 property_double (gamma, _("Gamma"), 2.0)
     description (_("Falloff linearity"))
-    value_range (1.0, 20.0)
+    value_range (0.0, 10.0)
 
 property_double (proportion, _("Proportion"), 1.0)
     description(_("How close we are to image proportions"))
@@ -85,8 +85,9 @@ property_double (rotation, _("Rotation"), 0.0)
 static void
 prepare (GeglOperation *operation)
 {
-  gegl_operation_set_format (operation, "input", babl_format ("RaGaBaA float"));
-  gegl_operation_set_format (operation, "output", babl_format ("RaGaBaA float"));
+  const Babl *space = gegl_operation_get_source_space (operation, "input");
+  gegl_operation_set_format (operation, "input", babl_format_with_space ("RaGaBaA float", space));
+  gegl_operation_set_format (operation, "output", babl_format_with_space ("RaGaBaA float", space));
 }
 
 /* conversion function mapping between scale and aspect
@@ -333,11 +334,12 @@ process (GeglOperation       *operation,
       if (strength>1.0)
         strength = 1.0;
 
-      if (o->gamma > 0.9999 && o->gamma < 2.0001)
+      if (o->gamma > 1.9999 && o->gamma < 2.0001)
         strength *= strength;  /* fast path for default gamma */
       else if (o->gamma != 1.0)
         strength = powf(strength, o->gamma); /* this gamma factor is
-                                              * very expensive..
+                                              * very expensive.. and precision
+                                              * is not very important
                                               */
 
       out_pixel[0]=in_pixel[0] * (1.0-strength) + color[0] * strength;
