@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright (c) 2010, 2011 Mukund Sivaraman <muks@banu.com>
  */
@@ -435,12 +435,12 @@ process (GeglOperation       *operation,
           switch (depth)
             {
             case 16:
-              gegl_buffer_set (output, &rect, 0, babl_format ("R'G'B' u16"),
+              gegl_buffer_set (output, &rect, 0, p->format,
                                data_s, GEGL_AUTO_ROWSTRIDE);
               break;
 
             case 8:
-              gegl_buffer_set (output, &rect, 0, babl_format ("R'G'B' u8"),
+              gegl_buffer_set (output, &rect, 0, p->format,
                                data_b, GEGL_AUTO_ROWSTRIDE);
 	      break;
 
